## Provide functions that handle old content as FP would do

from .wpfilters import *
from .footnotes import Footnotes
from .readmore import Readmore
from .fpbbcode import FpBBCode, BBPlugins

_bbcode = FpBBCode()

## A compat version of apply_filters from WordPress.
#
# This version supports only filters that have one argument
#
# \param filters The chain of filters to execute
# \param arg The argument to pass to the first filter
def _applyFilters(filters, arg):
    for priority in sorted(filters.keys()):
        for filter in filters[priority]:
            arg = filter(arg)

    return arg

## Set the manager of BBCode "plugins" (see fpbbcode.py for further details)
#
# \param class_ A class like (or even better, child) fpbbcode.DefaultPlugins
def setBBplugins(class_):
    global _bbcode
    _bbcode = FpBBCode(class_)

## Apply filters to show the complete entry (i.e. single entry page)
#
# \param text The text of the entry
# \param id_ The id of the entry
# \return The elaborated text
def the_content(text, id_):
    rm = Readmore(id_, None)

    filters = {
        0:  [Footnotes(id_).apply],
        1:  [_bbcode.entry, rm.applyFullManual],
        10: [convert_chars, wpautop, wptexturize],
        15: [rm.applyFullAuto]
    }

    return _applyFilters(filters, text)

## Apply filters to show the excerpt of an entry (e.g. archives page)
#
# \param text The text of the entry
# \param id_ The id of the entry
# \param permalink The URL to the page that shows only this entry
# \return The elaborated text
def the_excerpt(text, id_, permalink):
    rm = Readmore(id_, permalink)

    filters = {
        0:  [Footnotes(id_).apply],
        1:  [_bbcode.entry, rm.applyPreviewManual],
        10: [convert_chars, wpautop, wptexturize],
        15: [rm.applyPreviewAuto]
    }

    return _applyFilters(filters, text)

## Apply filters to show a comment
#
# \param text The text of the comment
# \return The elaborated text
def the_comment_content(text):
    # Notice that BBCode is set to make URL clickable and escape HTML
    filters = {
        1:  [_bbcode.comment],
        10: [convert_chars, wpautop, wptexturize],
    }

    return _applyFilters(filters, text)
